# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# FailedOperation.AddUsersToUserGroup
FAILEDOPERATION_ADDUSERSTOUSERGROUP = 'FailedOperation.AddUsersToUserGroup'

# FailedOperation.AppIdIsNull
FAILEDOPERATION_APPIDISNULL = 'FailedOperation.AppIdIsNull'

# FailedOperation.AppIdNotExited
FAILEDOPERATION_APPIDNOTEXITED = 'FailedOperation.AppIdNotExited'

# FailedOperation.AppIdNotFound
FAILEDOPERATION_APPIDNOTFOUND = 'FailedOperation.AppIdNotFound'

# FailedOperation.ChildOrgNodeWithUsersCannotBeDeleted
FAILEDOPERATION_CHILDORGNODEWITHUSERSCANNOTBEDELETED = 'FailedOperation.ChildOrgNodeWithUsersCannotBeDeleted'

# FailedOperation.CreateOrgNodeFailure
FAILEDOPERATION_CREATEORGNODEFAILURE = 'FailedOperation.CreateOrgNodeFailure'

# FailedOperation.CreateUserFailure
FAILEDOPERATION_CREATEUSERFAILURE = 'FailedOperation.CreateUserFailure'

# FailedOperation.CreateUserGroupFailure
FAILEDOPERATION_CREATEUSERGROUPFAILURE = 'FailedOperation.CreateUserGroupFailure'

# FailedOperation.CustomizedParentOrgNodeIdExisted
FAILEDOPERATION_CUSTOMIZEDPARENTORGNODEIDEXISTED = 'FailedOperation.CustomizedParentOrgNodeIdExisted'

# FailedOperation.DeleteOrgNodeFailure
FAILEDOPERATION_DELETEORGNODEFAILURE = 'FailedOperation.DeleteOrgNodeFailure'

# FailedOperation.DeleteUserGroupFailure
FAILEDOPERATION_DELETEUSERGROUPFAILURE = 'FailedOperation.DeleteUserGroupFailure'

# FailedOperation.DescribeOrgNodeFailure
FAILEDOPERATION_DESCRIBEORGNODEFAILURE = 'FailedOperation.DescribeOrgNodeFailure'

# FailedOperation.GroupIdNotFound
FAILEDOPERATION_GROUPIDNOTFOUND = 'FailedOperation.GroupIdNotFound'

# FailedOperation.ListUserGroupsOfUserFailure
FAILEDOPERATION_LISTUSERGROUPSOFUSERFAILURE = 'FailedOperation.ListUserGroupsOfUserFailure'

# FailedOperation.ListUsersInOrgNodeFailure
FAILEDOPERATION_LISTUSERSINORGNODEFAILURE = 'FailedOperation.ListUsersInOrgNodeFailure'

# FailedOperation.ListUsersInUserGroupFailure
FAILEDOPERATION_LISTUSERSINUSERGROUPFAILURE = 'FailedOperation.ListUsersInUserGroupFailure'

# Operation failed.
FAILEDOPERATION_OPERATIONFAILURE = 'FailedOperation.OperationFailure'

# FailedOperation.OrgNodeIdNotExist
FAILEDOPERATION_ORGNODEIDNOTEXIST = 'FailedOperation.OrgNodeIdNotExist'

# FailedOperation.OrgNodeNotExist
FAILEDOPERATION_ORGNODENOTEXIST = 'FailedOperation.OrgNodeNotExist'

# FailedOperation.OrgNodeRootCannotBeDeleted
FAILEDOPERATION_ORGNODEROOTCANNOTBEDELETED = 'FailedOperation.OrgNodeRootCannotBeDeleted'

# FailedOperation.OrgNodeWithUsersCannotBeDeleted
FAILEDOPERATION_ORGNODEWITHUSERSCANNOTBEDELETED = 'FailedOperation.OrgNodeWithUsersCannotBeDeleted'

# FailedOperation.ParentOrgNodeIdNotFound
FAILEDOPERATION_PARENTORGNODEIDNOTFOUND = 'FailedOperation.ParentOrgNodeIdNotFound'

# FailedOperation.ParentOrgNodeIsEmpty
FAILEDOPERATION_PARENTORGNODEISEMPTY = 'FailedOperation.ParentOrgNodeIsEmpty'

# FailedOperation.PersonNotFound
FAILEDOPERATION_PERSONNOTFOUND = 'FailedOperation.PersonNotFound'

# FailedOperation.RemoveUsersFromUserGroupFailure
FAILEDOPERATION_REMOVEUSERSFROMUSERGROUPFAILURE = 'FailedOperation.RemoveUsersFromUserGroupFailure'

# FailedOperation.TimeFormatIsIllegal
FAILEDOPERATION_TIMEFORMATISILLEGAL = 'FailedOperation.TimeFormatIsIllegal'

# FailedOperation.UserAlreadyExistedInUserGroup
FAILEDOPERATION_USERALREADYEXISTEDINUSERGROUP = 'FailedOperation.UserAlreadyExistedInUserGroup'

# 获取用户被授权访问的应用列表失败。
FAILEDOPERATION_USERAUTHLISTFAILED = 'FailedOperation.UserAuthListFailed'

# 设定的时间格式不合法。
FAILEDOPERATION_USEREXPRIATIONTIMEISILLEGAL = 'FailedOperation.UserExpriationTimeIsIllegal'

# 用户组不存在。
FAILEDOPERATION_USERGROUPNOTEXIST = 'FailedOperation.UserGroupNotExist'

# FailedOperation.UserGroupNotExisted
FAILEDOPERATION_USERGROUPNOTEXISTED = 'FailedOperation.UserGroupNotExisted'

# FailedOperation.UserNameExisted
FAILEDOPERATION_USERNAMEEXISTED = 'FailedOperation.UserNameExisted'

# FailedOperation.UserNotExistedInUserGroup
FAILEDOPERATION_USERNOTEXISTEDINUSERGROUP = 'FailedOperation.UserNotExistedInUserGroup'

# FailedOperation.UserPhoneExisted
FAILEDOPERATION_USERPHONEEXISTED = 'FailedOperation.UserPhoneExisted'

# 参数不合法。
INVALIDPARAMETER_PARAMETERLLLEGAL = 'InvalidParameter.Parameterlllegal'

# InvalidParameter.PasswordIsIllegal
INVALIDPARAMETER_PASSWORDISILLEGAL = 'InvalidParameter.PasswordIsIllegal'
